@@ -22,23 +22,25 @@ set -e
 # values to check
 initTestData() {
     #-- fill test data arrays
+    nextVersion="6.1"
     
     # Number of component, action and viewer extensions
-    componentExtensionCount=( [5.3]=15 [5.2]=15  [5.1]=14  [5.0]=14  [4.1]=14  [4.0]=14   )
-    actionExtensionCount=(    [5.3]=34 [5.2]=34  [5.1]=33  [5.0]=33  [4.1]=27  [4.0]=27   )
-    viewerExtensionCount=(    [5.3]=10 [5.2]=10  [5.1]=10  [5.0]=10                       )
+    componentExtensionCount=( [$nextVersion]=15 [6.0]=15 [5.2]=15  [5.1]=14  [5.0]=14  [4.1]=14  [4.0]=14   )
+    actionExtensionCount=(    [$nextVersion]=39 [6.0]=39 [5.2]=34  [5.1]=33  [5.0]=33  [4.1]=27  [4.0]=27   )
+    viewerExtensionCount=(    [$nextVersion]=10 [6.0]=10 [5.2]=10  [5.1]=10  [5.0]=10                       )
     
     # Number of different file format/extension manages by the component extensions
-    fileExtensionCount=(      [5.3]=38 [5.2]=38  [5.1]=37  [5.0]=37  [4.1]=37  [4.0]=37   )
+    fileExtensionCount=(      [$nextVersion]=38 [6.0]=38 [5.2]=38  [5.1]=37  [5.0]=37  [4.1]=37  [4.0]=37   )
     
     # Number of actions provided by the action extensions
-    actionCount=(             [5.3]=115 [5.2]=115 [5.1]=111 [5.0]=111 [4.1]=105 [4.0]=105 )
+    actionCount=(             [$nextVersion]=131 [6.0]=131 [5.2]=115 [5.1]=111 [5.0]=111 [4.1]=105 [4.0]=105 )
     
     # Number of viewers managed by the viewer extensions
-    viewerCount=(             [5.3]=13 [5.2]=13  [5.1]=13  [5.0]=13                       )
+    viewerCount=(             [$nextVersion]=13 [6.0]=13 [5.2]=13  [5.1]=13  [5.0]=13                       )
 
     #-- extensionCount is just the sum of all three extension counts
-    extensionCount=(          [5.3]=$((componentExtensionCount[5.3] + actionExtensionCount[5.3] + viewerExtensionCount[5.3]))
+    extensionCount=(          [$nextVersion]=$((componentExtensionCount[$nextVersion] + actionExtensionCount[$nextVersion] + viewerExtensionCount[$nextVersion]))
+                              [6.0]=$((componentExtensionCount[6.0] + actionExtensionCount[6.0] + viewerExtensionCount[6.0]))
                               [5.2]=$((componentExtensionCount[5.2] + actionExtensionCount[5.2] + viewerExtensionCount[5.2]))
                               [5.1]=$((componentExtensionCount[5.1] + actionExtensionCount[5.1] + viewerExtensionCount[5.1]))
                               [5.0]=$((componentExtensionCount[5.0] + actionExtensionCount[5.0] + viewerExtensionCount[5.0]))
@@ -46,7 +48,8 @@ initTestData() {
                               [4.0]=$((componentExtensionCount[4.0] + actionExtensionCount[4.0]))  )
 
     #-- Release date
-    releaseDate=(             [5.3]="not yet released, current development version" \
+    releaseDate=(             [$nextVersion]="not yet released, current development version" \
+                              [6.0]="19 December 2025" \
                               [5.2]="15 February 2024" \
                               [5.1]="28 July 2023" \
                               [5.0]="30 April 2021" \
